// src/appmarket-v1-app-plans-app-plans.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/appmarket-v1-app-plans-app-plans.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixAppmarketAppPlansV1AppsPlansUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/apps-plans",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/app-market/apps-plans",
        destPath: "/api"
      },
      {
        srcPath: "/api/apps-plans",
        destPath: ""
      },
      {
        srcPath: "/apps-plans",
        destPath: ""
      }
    ],
    "bo._base_domain_": [
      {
        srcPath: "/_api/apps-plans",
        destPath: ""
      },
      {
        srcPath: "/apps-plans",
        destPath: ""
      }
    ],
    "wixbo.ai": [
      {
        srcPath: "/_api/apps-plans",
        destPath: ""
      },
      {
        srcPath: "/apps-plans",
        destPath: ""
      }
    ],
    "wix-bo.com": [
      {
        srcPath: "/_api/apps-plans",
        destPath: ""
      },
      {
        srcPath: "/apps-plans",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/apps-plans",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/apps-plans",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/apps-plans",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/apps-plans",
        destPath: ""
      },
      {
        srcPath: "/_api/apps-plans",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/apps-plans",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_app-management_app-plans";
function listAppPlansByAppId(payload) {
  function __listAppPlansByAppId({ host }) {
    const metadata = {
      entityFqdn: "wix.appmarket.v1.app_plans",
      method: "GET",
      methodFqn: "wix.appmarket.app_plans.v1.AppsPlans.ListAppPlansByAppId",
      packageName: PACKAGE_NAME,
      url: resolveWixAppmarketAppPlansV1AppsPlansUrl({
        protoPath: "/v1/apps-plans/{appIds}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "appPlans.plans.prices.discount.saleOptions.startDate" },
            { path: "appPlans.plans.prices.discount.saleOptions.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __listAppPlansByAppId;
}

// src/appmarket-v1-app-plans-app-plans.universal.ts
var SaleType = /* @__PURE__ */ ((SaleType2) => {
  SaleType2["SALE_TYPE_UNSPECIFIED"] = "SALE_TYPE_UNSPECIFIED";
  SaleType2["CYBER_MONDAY"] = "CYBER_MONDAY";
  SaleType2["NOVEMBER_SALE"] = "NOVEMBER_SALE";
  SaleType2["BLACK_FRIDAY"] = "BLACK_FRIDAY";
  SaleType2["DEVELOPER_SALE"] = "DEVELOPER_SALE";
  return SaleType2;
})(SaleType || {});
var DiscountType = /* @__PURE__ */ ((DiscountType2) => {
  DiscountType2["DISCOUNT_TYPE_UNSPECIFIED"] = "DISCOUNT_TYPE_UNSPECIFIED";
  DiscountType2["FIXED_AMOUNT"] = "FIXED_AMOUNT";
  DiscountType2["PERCENTAGE"] = "PERCENTAGE";
  return DiscountType2;
})(DiscountType || {});
var SourceType = /* @__PURE__ */ ((SourceType2) => {
  SourceType2["SOURCE_TYPE_UNSPECIFIED"] = "SOURCE_TYPE_UNSPECIFIED";
  SourceType2["SALE"] = "SALE";
  SourceType2["APP_BENEFIT"] = "APP_BENEFIT";
  return SourceType2;
})(SourceType || {});
var DurationUnit = /* @__PURE__ */ ((DurationUnit2) => {
  DurationUnit2["UNKNOWN_UNIT"] = "UNKNOWN_UNIT";
  DurationUnit2["MONTH"] = "MONTH";
  DurationUnit2["YEAR"] = "YEAR";
  return DurationUnit2;
})(DurationUnit || {});
var CycleType = /* @__PURE__ */ ((CycleType2) => {
  CycleType2["UNKNOWN_TYPE"] = "UNKNOWN_TYPE";
  CycleType2["ONE_TIME"] = "ONE_TIME";
  CycleType2["RECURRING"] = "RECURRING";
  return CycleType2;
})(CycleType || {});
var BillingSource = /* @__PURE__ */ ((BillingSource2) => {
  BillingSource2["UNKNOWN"] = "UNKNOWN";
  BillingSource2["WIX"] = "WIX";
  BillingSource2["EXTERNAL"] = "EXTERNAL";
  return BillingSource2;
})(BillingSource || {});
var TaxType = /* @__PURE__ */ ((TaxType2) => {
  TaxType2["NOT_APPLICABLE"] = "NOT_APPLICABLE";
  TaxType2["VAT"] = "VAT";
  TaxType2["GST"] = "GST";
  return TaxType2;
})(TaxType || {});
async function listAppPlansByAppId2(appIds) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({ appIds });
  const reqOpts = listAppPlansByAppId(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { appIds: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["appIds"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/appmarket-v1-app-plans-app-plans.public.ts
function listAppPlansByAppId3(httpClient) {
  return (appIds) => listAppPlansByAppId2(
    appIds,
    // @ts-ignore
    { httpClient }
  );
}

// src/appmarket-v1-app-plans-app-plans.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
var listAppPlansByAppId4 = /* @__PURE__ */ createRESTModule(listAppPlansByAppId3);
export {
  BillingSource,
  CycleType,
  DiscountType,
  DurationUnit,
  SaleType,
  SourceType,
  TaxType,
  listAppPlansByAppId4 as listAppPlansByAppId
};
//# sourceMappingURL=index.mjs.map