import { i as ListAppPlansByAppIdRequest$1, L as ListAppPlansByAppIdResponse$1 } from './appmarket-v1-app-plans-app-plans.universal-BX_XsPPf.mjs';

interface AppPlans {
    /** App ID, as defined in the [app dashboard](https://dev.wix.com/apps/my-apps?viewId=active-apps-view). */
    id?: string;
    /**
     * List of the app's pricing plans.
     *
     * Min: `0` plans
     * Max: `50` plans
     * @maxSize 50
     */
    plans?: Plan[];
}
declare enum DiscountType {
    DISCOUNT_TYPE_UNSPECIFIED = "DISCOUNT_TYPE_UNSPECIFIED",
    /** Discount is a fixed amount in USD. */
    FIXED_AMOUNT = "FIXED_AMOUNT",
    /** Discount is a percentage of the total price. */
    PERCENTAGE = "PERCENTAGE"
}
/** @enumType */
type DiscountTypeWithLiterals = DiscountType | 'DISCOUNT_TYPE_UNSPECIFIED' | 'FIXED_AMOUNT' | 'PERCENTAGE';
interface Cycle {
    /**
     * Type of the billing cycle.
     *
     * + `"UNKNOWN_UNIT"`:  There is no information about the billing cycle.
     * + `"ONE_TIME"`:  The customer pays for unlimited usage of the app with a single payment.
     * + `"RECURRING"`: The customer pays for a subscription to the app on a recurring schedule.
     */
    cycleType?: CycleTypeWithLiterals;
    /** Duration of the billing cycle. Available only for `{"cycleType": "RECURRING"}`. */
    cycleDuration?: Duration;
}
declare enum DurationUnit {
    /** unknown interval unit */
    UNKNOWN_UNIT = "UNKNOWN_UNIT",
    /** month */
    MONTH = "MONTH",
    /** year */
    YEAR = "YEAR"
}
/** @enumType */
type DurationUnitWithLiterals = DurationUnit | 'UNKNOWN_UNIT' | 'MONTH' | 'YEAR';
declare enum CycleType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    ONE_TIME = "ONE_TIME",
    RECURRING = "RECURRING"
}
/** @enumType */
type CycleTypeWithLiterals = CycleType | 'UNKNOWN_TYPE' | 'ONE_TIME' | 'RECURRING';
interface Duration {
    /** Unit of the billing cycle. */
    unit?: DurationUnitWithLiterals;
    /** Count of units that make up the billing cycle. */
    count?: number;
}
interface UsageBasedDetails {
    /**
     * Smallest possible amount that your app charges customers in usage-based
     * pricing. For example, the price of a single SMS message if your
     * app charges customers for sending text messages. Always in
     * [USD](https://en.wikipedia.org/wiki/United_States_dollar).
     *
     * Min: `0.00`
     * Max: 1024 characters
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0.00 }
     * @maxLength 1024
     */
    minimumChargeIncrement?: string | null;
    /**
     * Recurring, monthly base fee in usage-based pricing that your app
     * charges customers regardless of how much they use your app.
     *
     * Min: `0.00`
     * Max: 1024 characters
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0.00 }
     * @maxLength 1024
     */
    monthlyBaseFee?: string | null;
    /**
     * Description of the usage-based pricing plan, as defined in the [app dashboard](https://dev.wix.com/apps/my-apps?viewId=active-apps-view).
     *
     * Max: 1024 characters
     */
    customChargeDescription?: string | null;
}
interface Discount extends DiscountSourceDataOneOf {
    type?: DiscountTypeWithLiterals;
    /**
     * Discount amount
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0.00, maxScale:2 }
     * @maxLength 1024
     */
    amount?: string;
    /**
     * Price without taxes. For yearly plans, Wix calculates and returns the
     * average price per month. You can get the full price by multiplying the
     * returned price with 12.
     * Min: `0.00`
     * Max: 1024 characters
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0.00, maxScale:2 }
     * @maxLength 1024
     */
    priceBeforeTax?: string;
    /**
     * Total price including taxes.
     * Min: `0.00`
     * Max: 1024 characters
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0.00, maxScale:2 }
     * @maxLength 1024
     */
    totalPrice?: string;
}
/** @oneof */
interface DiscountSourceDataOneOf {
}
declare enum BillingSource {
    UNKNOWN = "UNKNOWN",
    /** plan billing and charges is managed by Wix */
    WIX = "WIX",
    /** plan billing and charges is managed by the app */
    EXTERNAL = "EXTERNAL"
}
/** @enumType */
type BillingSourceWithLiterals = BillingSource | 'UNKNOWN' | 'WIX' | 'EXTERNAL';
interface Price {
    /**
     * Price without taxes. For yearly plans, Wix calculates and returns the
     * average price per month. You can get the full price by multiplying the
     * returned price by 12.
     *
     * Min: `0.00`
     * Max: 1024 characters
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0.00 }
     * @maxLength 1024
     */
    priceBeforeTax?: string;
    /**
     * Total price including taxes.
     *
     * Min: `0.00`
     * Max: 1024 characters
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:0.00 }
     * @maxLength 1024
     */
    totalPrice?: string;
    /** Information about the plan's recurring billing cycle or single payment. */
    billingCycle?: Cycle;
    /**
     * Details about the plan's usage-based pricing.
     * Available only for plans with
     * [usage-based pricing](https://dev.wix.com/docs/build-apps/build-your-app/pricing-plans/usage-based-pricing).
     */
    usageBaseOptions?: UsageBasedDetails;
    discount?: Discount;
    billingSource?: BillingSourceWithLiterals;
    /**
     * Can be shown instead of plan price - used for dynamic plans
     * @maxLength 140
     */
    customPaymentTitle?: string | null;
}
interface Plan {
    /**
     * ID of the app plan.
     * @format GUID
     * @readonly
     */
    id?: string;
    /**
     * ID of your app's pricing plan, as displayed in the [app dashboard](https://dev.wix.com/apps/my-apps?viewId=active-apps-view).
     * Identical to `vendorProductId` in the
     * [Paid Plan Purchased webhook](https://dev.wix.com/docs/rest/api-reference/app-management/apps/app-instance/paid-plan-purchased).
     */
    vendorId?: string;
    /** Name of your app's pricing plan, as defined by you in the [app dashboard](https://dev.wix.com/apps/my-apps?viewId=active-apps-view). */
    name?: string;
    /**
     * List of your plan's benefits, as defined by you in the [app dashboard](https://dev.wix.com/apps/my-apps?viewId=active-apps-view).
     * Currently, the benefits are available only in English.
     *
     * Min: `0` benefits
     * Max: `4` benefits
     * Max per benefit: 1024 characters
     * @maxSize 4
     * @maxLength 1024
     */
    benefits?: string[];
    /**
     * List of the plan's prices. Available only when the plan's prices are managed
     * by Wix and not externally.
     *
     * Min: `0` prices
     * Max: `10` prices
     * @maxSize 10
     */
    prices?: Price[];
}
interface ListAppPlansByAppIdRequest {
    /**
     * List of app IDs to retrieve plans for.
     *
     * Min: 1 app ID
     * Max: 100 app IDs
     * @minSize 1
     * @maxSize 100
     */
    appIds: string[];
}
interface ListAppPlansByAppIdResponse {
    /**
     * Tax settings. Wix calculates the tax settings based on the country code that
     * you pass in the call's header. If you don't pass a country code in the header,
     * Wix calculates the tax settings based on the caller's IP address. Note that the
     * tax settings may not resolve properly if you call through a VPN.
     */
    taxSettings?: TaxSettings;
    /**
     * 3-letter currency code in [ISO-4217 alphabetic](https://en.wikipedia.org/wiki/ISO_4217#Active_codes)
     * format. Wix calculates the currency based on the country code that
     * you pass in the call's header. If you don't pass a country code in the header,
     * Wix calculates the currency based on the caller's IP address. Note that the
     * currency may not resolve properly if you call through a VPN.
     * @format CURRENCY
     */
    currency?: string;
    /**
     * Currency symbol in decimal HTML entity format. For example, `&#36;` for $
     * (United States Dollar). Wix calculates the currency symbol based on the
     * country code that you pass in the call's header. If you don't pass a country
     * code in the header, Wix calculates the tax settings based on the caller's IP
     * address. Note that the currency symbol may not resolve properly if you call
     * through a VPN.
     */
    currencySymbol?: string;
    /**
     * Retrieved app plans.
     *
     * Min: 0 plans
     * Max: 50 plans
     *
     * If any plans aren't returned, it's likely because they haven't been activated yet.
     * @maxSize 50
     */
    appPlans?: AppPlans[];
}
interface TaxSettings {
    /**
     * Whether you must display the total price including taxes in the given
     * country.
     */
    showPriceWithTax?: boolean;
    /**
     * Tax rate for the given country as percentage. Returned as `0` when
     * `{"showPriceWithTax": false}`.
     * @format DECIMAL_VALUE
     */
    percentage?: string | null;
    /**
     * Type of tax required in the given country.
     *
     * + `"NOT_APPLICABLE"`: The country doesn't require that you display the total price including taxes, or Wix failed to calculate the country based on the call's IP address.
     * + `"VAT"`: The given country requires that you display the total price including [value-added tax (VAT)](https://en.wikipedia.org/wiki/Value-added_tax).
     * + `"GST"`: The given country requires that you display the total price including [generation-skipping transfer tax (GST)](https://en.wikipedia.org/wiki/Generation-skipping_transfer_tax).
     */
    taxType?: TaxTypeWithLiterals;
}
declare enum TaxType {
    NOT_APPLICABLE = "NOT_APPLICABLE",
    VAT = "VAT",
    GST = "GST"
}
/** @enumType */
type TaxTypeWithLiterals = TaxType | 'NOT_APPLICABLE' | 'VAT' | 'GST';

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function listAppPlansByAppId(): __PublicMethodMetaInfo<'GET', {
    appIds: string;
}, ListAppPlansByAppIdRequest$1, ListAppPlansByAppIdRequest, ListAppPlansByAppIdResponse$1, ListAppPlansByAppIdResponse>;

export { type __PublicMethodMetaInfo, listAppPlansByAppId };
